# HyTools-lite

HyTools-lite is a stripped down version of the [hytools](https://github.com/EnSpec/hytools) hyperspectral image processing library. It has
minimal dependencies and only retains functions for reading ENVI binary and NEON HDF files and writing to ENVI binary files.

For documentation and examples see [hytools.readthedocs.io](https://hytools.readthedocs.io/en/latest/contents.html) and [hytools jupyter notebook](https://github.com/EnSpec/hytools/blob/master/examples/hytools_basics_notebook.ipynb)

## Dependecies
- h5py
- numpy

## Installation

```bash
pip install hy-tools-lite
```
